;; Generated package description from doric-themes.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "doric-themes" "0.6.0" "Highly legible minimalist themes with precise typography" '((emacs "29.1")) :commit "92c2123e1a3b6cb8ef30539c5b81952c4f7df692" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("faces" "theme" "accessibility") :url "https://github.com/protesilaos/doric-themes")
